@@ -25,6 +25,7 @@
 
 #include "mainwindow.h"
 #include "ui_mainwindow.h"
+#include "version.h"
 
 #include <QDebug>
 
@@ -39,6 +40,7 @@ MainWindow::MainWindow(QWidget *parent) :
     QDialog(parent),
     ui(new Ui::MainWindow)
 {
+    qDebug() << "Program Version:" << VERSION;
     ui->setupUi(this);
     if (ui->buttonOk->icon().isNull()) {
         ui->buttonOk->setIcon(QIcon(":/icons/dialog-ok.svg"));
@@ -68,7 +70,6 @@ MainWindow::MainWindow(QWidget *parent) :
 
     ui->buttonOk->setDisabled(true);
 
-    version = getVersion("repo-manager");
     this->setWindowTitle(tr("Repo Manager"));
     ui->tabWidget->setCurrentWidget(ui->tabantiX);
     refresh();
@@ -106,7 +107,7 @@ void MainWindow::replaceDebianRepos(const QString &url)
         QDir().mkdir("/etc/apt/sources.list.d/backups");
     }
 
-    foreach(QString file, files) {
+    for (const QString &file : files) {
         QFileInfo fileinfo(file);
 
         // backup file
@@ -126,13 +127,6 @@ void MainWindow::replaceDebianRepos(const QString &url)
                              tr("Your new selection will take effect the next time sources are updated."));
 }
 
-
-// Get version of the program
-QString MainWindow::getVersion(const QString &name)
-{
-    return shell->getOutput("dpkg-query -f '${Version}' -W " + name);
-}
-
 // List available repos
 QStringList MainWindow::readantiXRepos()
 {
@@ -148,7 +142,7 @@ QStringList MainWindow::readantiXRepos()
 
     // remove commented out lines
     QStringList repos;
-    foreach (QString line, file_content_list) {
+    for (const QString &line : file_content_list) {
         if (!line.startsWith("#")) {
             repos << line;
         }
@@ -190,7 +184,7 @@ void MainWindow::displayantiXRepos(const QStringList &repos, const QString &filt
             button->setChecked(true);
             ui->listWidget->scrollToItem(item);
         }
-        connect(button, SIGNAL(clicked(bool)),ui->buttonOk, SLOT(setEnabled(bool)));
+        connect(button, &QRadioButton::clicked, ui->buttonOk, &QPushButton::setEnabled);
     }
 }
 
@@ -208,8 +202,8 @@ void MainWindow::displayAllRepos(const QFileInfoList &apt_files)
 
     QTreeWidgetItem *topLevelItem;
     QTreeWidgetItem *topLevelItemDeb;
-    QFileInfo file_info;
-    foreach (file_info, apt_files) {
+
+    for (const QFileInfo &file_info : apt_files) {
         QString file_name = file_info.fileName();
         QString file = file_info.absoluteFilePath();
         topLevelItem = new QTreeWidgetItem;
@@ -224,9 +218,9 @@ void MainWindow::displayAllRepos(const QFileInfoList &apt_files)
         topLevelItem->setForeground(0, QBrush(Qt::darkGreen));
         topLevelItemDeb->setForeground(0, QBrush(Qt::darkGreen));
         // load file entries
-        QStringList entries = loadAptFile(file);
-        QString item;
-        foreach (item, entries) {
+        const QStringList entries = loadAptFile(file);
+
+        for (const QString &item : entries) {
             // add entries as childItem to treeWidget
             QTreeWidgetItem *childItem = new QTreeWidgetItem(topLevelItem);
             QTreeWidgetItem *childItemDeb = new QTreeWidgetItem(topLevelItemDeb);
@@ -277,7 +271,7 @@ void MainWindow::displaySelected(const QString &repo)
 // extract the URLs from the list of repos that contain country names and description
 void MainWindow::extractUrls(const QStringList &repos)
 {
-    foreach(QString line, repos) {
+    for (const QString &line : repos) {
         QStringList linelist = line.split("-");
         linelist.removeAt(0);
         listantiXurls += linelist.join("-").trimmed() + " ";
@@ -330,20 +324,20 @@ void MainWindow::replaceRepos(const QString &url)
     // get Debian version
     QString ver_num = getDebianVersion();
     QString ver_name;
-    if (ver_num == "8") {
-        ver_name = "jessie";
-    } else if (ver_num == "9") {
+    if (ver_num == "9") {
         ver_name = "stretch";
+    } else if (ver_num == "10") {
+        ver_name = "buster";
     }
 
     // for antiX repos
     QString antix_file = "/etc/apt/sources.list.d/antix.list";
-    if (url == "http://repo.antixlinux.com") {
-        repo_line_antix = "deb http://repo.antixlinux.com/" + ver_name + " " + ver_name + " main";
+    if (url == "http://mxrepo.com") {
+        repo_line_antix = "http://la.mxrepo.com/antix/" + ver_name + "/";
     } else {
-        repo_line_antix = "deb " + url + "/antix/" + ver_name + "/ " + ver_name + " main";
+        repo_line_antix = url + "/antix/" + ver_name + "/";
     }
-    cmd_antix = QString("sed -i 's;deb.*/" + ver_name + "/\\? " + ver_name + " main;%1;' %2").arg(repo_line_antix).arg(antix_file);
+    cmd_antix = QString("sed -i 's;https\\?://.*/" + ver_name + "/\\?;%1;' %2").arg(repo_line_antix).arg(antix_file);
 
     // check if both replacement were successful
     if (shell->run(cmd_antix) == 0 && shell->run(cmd_antix) == 0) {
@@ -375,8 +369,7 @@ QFileInfoList MainWindow::listAptFiles()
 void MainWindow::on_buttonOk_clicked()
 {
     if (queued_changes.size() > 0) {
-        QStringList changes;
-        foreach (changes, queued_changes) {
+        for (const QStringList &changes : queued_changes) {
             QString text, new_text, file_name;
             text = changes[0];
             new_text = changes[1];
@@ -400,10 +393,33 @@ void MainWindow::on_buttonAbout_clicked()
                        tr("Program for choosing the default APT repository") +
                        "</h3></p><p align=\"center\"><a href=\"http://mxlinux.org\">http://mxlinux.org</a><br /></p><p align=\"center\">" +
                        tr("Copyright (c) MX Linux") + "<br /><br /></p>", 0, this);
-    msgBox.addButton(tr("License"), QMessageBox::AcceptRole);
-    msgBox.addButton(tr("Cancel"), QMessageBox::NoRole);
-    if (msgBox.exec() == QMessageBox::AcceptRole) {
-        system("antix-viewer file:///usr/share/doc/repo-manager/license.html '" + tr("Repo Manager").toUtf8() + " " + tr("License").toUtf8() + "'");
+    QPushButton *btnLicense = msgBox.addButton(tr("License"), QMessageBox::HelpRole);
+    QPushButton *btnChangelog = msgBox.addButton(tr("Changelog"), QMessageBox::HelpRole);
+    QPushButton *btnCancel = msgBox.addButton(tr("Cancel"), QMessageBox::NoRole);
+    btnCancel->setIcon(QIcon::fromTheme("window-close"));
+
+    msgBox.exec();
+
+    if (msgBox.clickedButton() == btnLicense) {
+        QString url = "file:///usr/share/doc/mx-repo-manager/license.html";
+        displayDoc(url);
+    } else if (msgBox.clickedButton() == btnChangelog) {
+        QDialog *changelog = new QDialog(this);
+        changelog->resize(600, 500);
+
+        QTextEdit *text = new QTextEdit;
+        text->setReadOnly(true);
+        text->setText(shell->getOutput("zless /usr/share/doc/" + QFileInfo(QCoreApplication::applicationFilePath()).fileName()  + "/changelog.gz"));
+
+        QPushButton *btnClose = new QPushButton(tr("&Close"));
+        btnClose->setIcon(QIcon::fromTheme("window-close"));
+        connect(btnClose, &QPushButton::clicked, changelog, &QDialog::close);
+
+        QVBoxLayout *layout = new QVBoxLayout;
+        layout->addWidget(text);
+        layout->addWidget(btnClose);
+        changelog->setLayout(layout);
+        changelog->exec();
     }
     this->show();
 }
